pub trait NetworkBuilder<Node, Pool>: Sendwhere
Node: FullNodeTypes,
Pool: TransactionPool,{
type Network: FullNetwork
where <Self::Network as NetworkEventListenerProvider>::Primitives: NetPrimitivesFor<<<Node as FullNodeTypes>::Types as NodeTypes>::Primitives>;
// Required method
fn build_network(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
) -> impl Future<Output = Result<Self::Network, Report>> + Send;
}Expand description
A type that knows how to build the network implementation.
Required Associated Types
Sourcetype Network: FullNetwork
where
<Self::Network as NetworkEventListenerProvider>::Primitives: NetPrimitivesFor<<<Node as FullNodeTypes>::Types as NodeTypes>::Primitives>
type Network: FullNetwork where <Self::Network as NetworkEventListenerProvider>::Primitives: NetPrimitivesFor<<<Node as FullNodeTypes>::Types as NodeTypes>::Primitives>
The network built.
Required Methods
Sourcefn build_network(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
) -> impl Future<Output = Result<Self::Network, Report>> + Send
fn build_network( self, ctx: &BuilderContext<Node>, pool: Pool, ) -> impl Future<Output = Result<Self::Network, Report>> + Send
Launches the network implementation and returns the handle to it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".