ExtendRpcModules

Trait ExtendRpcModules 

pub trait ExtendRpcModules<Node, EthApi>: Send
where Node: FullNodeComponents, EthApi: EthApiTypes,
{ // Required method fn extend_rpc_modules( self: Box<Self>, ctx: RpcContext<'_, Node, EthApi>, ) -> Result<(), Report>; }
Event hook that is called when the rpc server is started.

Required Methods

fn extend_rpc_modules( self: Box<Self>, ctx: RpcContext<'_, Node, EthApi>, ) -> Result<(), Report>

The hook that is called once the rpc server is started.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Node, EthApi> ExtendRpcModules<Node, EthApi> for ()
where Node: FullNodeComponents, EthApi: EthApiTypes,

Source

fn extend_rpc_modules( self: Box<()>, _: RpcContext<'_, Node, EthApi>, ) -> Result<(), Report>

Implementors

Source

impl<Node, EthApi, F> ExtendRpcModules<Node, EthApi> for F
where F: FnOnce(RpcContext<'_, Node, EthApi>) -> Result<(), Report> + Send, Node: FullNodeComponents, EthApi: EthApiTypes,