OnRpcStarted

Trait OnRpcStarted 

pub trait OnRpcStarted<Node, EthApi>: Send
where Node: FullNodeComponents, EthApi: EthApiTypes,
{ // Required method fn on_rpc_started( self: Box<Self>, ctx: RpcContext<'_, Node, EthApi>, handles: RethRpcServerHandles, ) -> Result<(), Report>; }
Event hook that is called once the rpc server is started.

Required Methods

fn on_rpc_started( self: Box<Self>, ctx: RpcContext<'_, Node, EthApi>, handles: RethRpcServerHandles, ) -> Result<(), Report>

The hook that is called once the rpc server is started.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Node, EthApi> OnRpcStarted<Node, EthApi> for ()
where Node: FullNodeComponents, EthApi: EthApiTypes,

Source

fn on_rpc_started( self: Box<()>, _: RpcContext<'_, Node, EthApi>, _: RethRpcServerHandles, ) -> Result<(), Report>

Implementors

Source

impl<Node, EthApi, F> OnRpcStarted<Node, EthApi> for F
where F: FnOnce(RpcContext<'_, Node, EthApi>, RethRpcServerHandles) -> Result<(), Report> + Send, Node: FullNodeComponents, EthApi: EthApiTypes,