pub trait Node<N>: NodeTypes + Clonewhere
N: FullNodeTypes,{
type ComponentsBuilder: NodeComponentsBuilder<N>;
type AddOns: NodeAddOns<NodeAdapter<N, <Self::ComponentsBuilder as NodeComponentsBuilder<N>>::Components>>;
// Required methods
fn components_builder(&self) -> Self::ComponentsBuilder;
fn add_ons(&self) -> Self::AddOns;
// Provided method
fn disabled_stages() -> &'static [StageId] { ... }
}Expand description
A crate::Node is a NodeTypes that comes with preconfigured components.
This can be used to configure the builder with a preset of components.
Required Associated Types
Sourcetype ComponentsBuilder: NodeComponentsBuilder<N>
type ComponentsBuilder: NodeComponentsBuilder<N>
The type that builds the node’s components.
Sourcetype AddOns: NodeAddOns<NodeAdapter<N, <Self::ComponentsBuilder as NodeComponentsBuilder<N>>::Components>>
type AddOns: NodeAddOns<NodeAdapter<N, <Self::ComponentsBuilder as NodeComponentsBuilder<N>>::Components>>
Exposes the customizable node add-on types.
Required Methods
Sourcefn components_builder(&self) -> Self::ComponentsBuilder
fn components_builder(&self) -> Self::ComponentsBuilder
Returns a NodeComponentsBuilder for the node.
Provided Methods
Sourcefn disabled_stages() -> &'static [StageId]
fn disabled_stages() -> &'static [StageId]
Returns the stages that should be disabled for this node.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".