TransactionRoot

Type Alias TransactionRoot 

pub type TransactionRoot = FixedBytes<32>;
Pre-computed transaction root.

When provided to Consensus::validate_block_pre_execution_with_tx_root, this allows skipping transaction trie reconstruction from the block body.

Aliased Type

#[repr(transparent)]
pub struct TransactionRoot(pub [u8; 32]);

Tuple Fields

0: [u8; 32]

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes