ValueWithSubKey

Trait ValueWithSubKey 

pub trait ValueWithSubKey {
    type SubKey;

    // Required method
    fn get_subkey(&self) -> Self::SubKey;
}
Trait for DupSort table values that contain a subkey.

This trait allows extracting the subkey from a value during database iteration, enabling proper range queries and filtering on DupSort tables.

Required Associated Types

type SubKey

The type of the subkey.

Required Methods

fn get_subkey(&self) -> Self::SubKey

Extract the subkey from the value.

Implementations on Foreign Types

Source

impl ValueWithSubKey for AccountBeforeTx

Source

impl ValueWithSubKey for StorageBeforeTx

Source

impl ValueWithSubKey for PackedStorageTrieEntry

Source

impl ValueWithSubKey for StorageTrieEntry

Implementors