BlockAccessListsClient

Trait BlockAccessListsClient 

pub trait BlockAccessListsClient: DownloadClient {
    type Output: Future<Output = Result<WithPeerId<BlockAccessLists>, RequestError>> + Send + Sync + Unpin;

    // Required method
    fn get_block_access_lists_with_priority_and_requirement(
        &self,
        hashes: Vec<FixedBytes<32>>,
        priority: Priority,
        requirement: BalRequirement,
    ) -> Self::Output;

    // Provided methods
    fn get_block_access_lists(
        &self,
        hashes: Vec<FixedBytes<32>>,
    ) -> Self::Output { ... }
    fn get_block_access_lists_with_requirement(
        &self,
        hashes: Vec<FixedBytes<32>>,
        requirement: BalRequirement,
    ) -> Self::Output { ... }
    fn get_block_access_lists_with_priority(
        &self,
        hashes: Vec<FixedBytes<32>>,
        priority: Priority,
    ) -> Self::Output { ... }
}
A client capable of downloading block access lists.

Required Associated Types

type Output: Future<Output = Result<WithPeerId<BlockAccessLists>, RequestError>> + Send + Sync + Unpin

The bal type this client fetches.

Required Methods

fn get_block_access_lists_with_priority_and_requirement( &self, hashes: Vec<FixedBytes<32>>, priority: Priority, requirement: BalRequirement, ) -> Self::Output

Fetches the block access lists for given hashes with priority and BAL availability policy.

Provided Methods

fn get_block_access_lists(&self, hashes: Vec<FixedBytes<32>>) -> Self::Output

Fetches the block access lists for given hashes.

fn get_block_access_lists_with_requirement( &self, hashes: Vec<FixedBytes<32>>, requirement: BalRequirement, ) -> Self::Output

Fetches the block access lists for given hashes with the requested BAL availability policy.

fn get_block_access_lists_with_priority( &self, hashes: Vec<FixedBytes<32>>, priority: Priority, ) -> Self::Output

Fetches the block access lists for given hashes with priority

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T> BlockAccessListsClient for &'a T

Source

impl<T> BlockAccessListsClient for Arc<T>

Source

impl<T> BlockAccessListsClient for Box<T>

Implementors