pub const fn is_connection_failed_reputation(reputation: i32) -> boolExpand description
Returns true if the given reputation is below the FAILED_TO_CONNECT_REPUTATION_CHANGE
threshold
pub const fn is_connection_failed_reputation(reputation: i32) -> boolReturns true if the given reputation is below the FAILED_TO_CONNECT_REPUTATION_CHANGE
threshold