RocksTxRefArg

Type Alias RocksTxRefArg 

pub type RocksTxRefArg<'a> = Option<&'a RocksTx<'a>>;
Helper type for RocksDB transaction reference argument in reader constructors.

The Option allows callers to skip transaction creation when RocksDB isn’t needed (e.g., on legacy MDBX-only nodes).

Aliased Type

pub enum RocksTxRefArg<'a> {
    None,
    Some(&'a RocksTx<'a>),
}

Variants

1.0.0

None

No value.

1.0.0

Some(&'a RocksTx<'a>)

Some value of type T.

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.