Trait AuthorizationTr
pub trait AuthorizationTr {
// Required methods
fn authority(&self) -> Option<Address>;
fn chain_id(&self) -> Uint<256, 4>;
fn nonce(&self) -> u64;
fn address(&self) -> Address;
}Expand description
Authorization trait.
Required Methods
Authority address.
Note
Authority signature can be invalid, so this method returns None if the authority could not be recovered.
Valid signature Parity should be 0 or 1 and signature s-value should be less than SECP256K1N_HALF.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".