GasTracker

Struct GasTracker 

pub struct GasTracker { /* private fields */ }
Tracker for gas during execution.

This is used to track the gas during execution.

Implementations



impl GasTracker

pub const fn new(gas_limit: u64, remaining: u64, reservoir: u64) -> GasTracker

Creates a new GasTracker with the given remaining gas and reservoir.

pub const fn new_used_gas( gas_limit: u64, used_gas: u64, reservoir: u64, ) -> GasTracker

Creates a new GasTracker with the given used gas and reservoir.

pub const fn limit(&self) -> u64

Returns the gas limit.

pub fn set_limit(&mut self, val: u64)

Sets the gas limit.

pub const fn remaining(&self) -> u64

Returns the remaining gas.

pub fn set_remaining(&mut self, val: u64)

Sets the remaining gas.

pub const fn reservoir(&self) -> u64

Returns the reservoir gas.

pub fn set_reservoir(&mut self, val: u64)

Sets the reservoir gas.

pub const fn state_gas_spent(&self) -> u64

Returns the state gas spent.

pub fn set_state_gas_spent(&mut self, val: u64)

Sets the state gas spent.

pub const fn refunded(&self) -> i64

Returns the refunded gas.

pub fn set_refunded(&mut self, val: i64)

Sets the refunded gas.

pub fn record_regular_cost(&mut self, cost: u64) -> bool

Records a regular gas cost.

Deducts from remaining. Returns false if insufficient gas.

pub fn record_state_cost(&mut self, cost: u64) -> bool

Records a state gas cost (EIP-8037 reservoir model).

State gas charges deduct from the reservoir first. If the reservoir is exhausted, remaining charges spill into remaining (requiring remaining >= cost). Tracks state gas spent.

Returns false if total remaining gas is insufficient.

pub fn record_refund(&mut self, refund: i64)

Records a refund value.

pub fn erase_cost(&mut self, returned: u64)

Erases a gas cost from remaining (returns gas from child frame).

pub fn spend_all(&mut self)

Spends all remaining gas excluding the reservoir.