Function i256_sign_compl
pub fn i256_sign_compl(val: &mut Uint<256, 4>) -> SignExpand description
Determines the sign of a 256-bit signed integer and converts it to its absolute value.
pub fn i256_sign_compl(val: &mut Uint<256, 4>) -> SignDetermines the sign of a 256-bit signed integer and converts it to its absolute value.