Type Alias InstructionExecResult
pub type InstructionExecResult<T = (), E = InstructionResult> = Result<T, E>;Expand description
Result type returned by instruction implementations.
Ok(()) means the instruction completed normally and execution should continue.
Err(result) means execution should halt with the given InstructionResult.
Aliased Type
pub enum InstructionExecResult<T = (), E = InstructionResult> {
Ok(T),
Err(E),
}Variants
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.