pub async fn fee_history_cache_new_blocks_task<St, Provider, N>(
fee_history_cache: FeeHistoryCache<<N as NodePrimitives>::BlockHeader>,
events: St,
provider: Provider,
cache: EthStateCache<N>,
)where
St: Stream<Item = CanonStateNotification<N>> + Unpin + 'static,
Provider: BlockReaderIdExt<Block = <N as NodePrimitives>::Block, Receipt = <N as NodePrimitives>::Receipt> + ChainSpecProvider + 'static,
N: NodePrimitives,
<N as NodePrimitives>::BlockHeader: BlockHeader + Clone,Expand description
Awaits for new chain events and directly inserts them into the cache so they’re available immediately before they need to be fetched from disk.