resolve_transaction

Function resolve_transaction 

pub fn resolve_transaction<DB, Tx, T>(
    tx: <<T as RpcConvert>::Network as RpcTypes>::TransactionRequest,
    default_gas_limit: u64,
    block_base_fee_per_gas: u64,
    chain_id: u64,
    db: &mut DB,
    converter: &T,
) -> Result<Recovered<Tx>, EthApiError>
where DB: Database, <DB as Database>::Error: Into<EthApiError>, T: RpcConvert, <T as RpcConvert>::Primitives: NodePrimitives<SignedTx = Tx>,
Goes over the list of TransactionRequests and populates missing fields trying to resolve them into primitive transactions.

This will set the defaults as defined in https://github.com/ethereum/execution-apis/blob/e56d3208789259d0b09fa68e9d8594aa4d73c725/docs/ethsimulatev1-notes.md#default-values-for-transactions