pub struct MultiConsumerLruCache<K, V, L, S>{ /* private fields */ }Expand description
A multi-consumer LRU cache.
Implementations
Sourceimpl<K, V, L, S> MultiConsumerLruCache<K, V, L, S>
impl<K, V, L, S> MultiConsumerLruCache<K, V, L, S>
Sourcepub fn queue(&mut self, key: K, sender: S) -> bool
pub fn queue(&mut self, key: K, sender: S) -> bool
Adds the sender to the queue for the given key.
Returns true if this is the first queued sender for the key
Sourcepub fn remove(&mut self, key: &K) -> Option<Vec<S>>where
V: InMemorySize,
pub fn remove(&mut self, key: &K) -> Option<Vec<S>>where
V: InMemorySize,
Remove consumers for a given key, this will also remove the key from the cache.
Sourcepub fn get(&mut self, key: &K) -> Option<&mut V>
pub fn get(&mut self, key: &K) -> Option<&mut V>
Returns a reference to the value for a given key and promotes that element to be the most recently used.
Sourcepub fn insert<'a>(
&mut self,
key: <L as Limiter<K, V>>::KeyToInsert<'a>,
value: V,
) -> bool
pub fn insert<'a>( &mut self, key: <L as Limiter<K, V>>::KeyToInsert<'a>, value: V, ) -> bool
Inserts a new element into the map.
Can fail if the element is rejected by the limiter or if we fail to grow an empty map.
See [LruMap::insert] for more info.
Sourcepub fn shrink_to(&mut self, min_capacity: usize)
pub fn shrink_to(&mut self, min_capacity: usize)
Shrinks the capacity of the queue with a lower limit.
Sourcepub fn update_cached_metrics(&mut self) -> bool
pub fn update_cached_metrics(&mut self) -> bool
Publishes the cached count and memory usage gauges if either changed since the last call.
Returns whether the gauges were written, so lookups that only hit the cache cost nothing.
Sourceimpl<K, V, S> MultiConsumerLruCache<K, V, ByLength, S>
impl<K, V, S> MultiConsumerLruCache<K, V, ByLength, S>
Sourcepub fn new(
max_len: u32,
cache_id: &str,
) -> MultiConsumerLruCache<K, V, ByLength, S>
pub fn new( max_len: u32, cache_id: &str, ) -> MultiConsumerLruCache<K, V, ByLength, S>
Creates a new empty map with a given max_len and metric label.