build_pool_with_panic_handler

Function build_pool_with_panic_handler 

pub fn build_pool_with_panic_handler(
    builder: ThreadPoolBuilder,
) -> Result<ThreadPool, ThreadPoolBuildError>
Available on crate feature rayon only.
Builds a rayon thread pool with a panic handler that prevents aborting the process.

Rust’s default panic hook already logs the panic message and backtrace to stderr, so the handler itself is intentionally a no-op.