Function thread_native_id
pub fn thread_native_id() -> u64Available on Android or DragonFly BSD or FreeBSD or iOS or Linux or macOS or NetBSD or OpenBSD or VxWorks or WebAssembly only.
Returns current thread id, which is the current OS’s native handle. It may or may not be equal or even related to rust’s thread id, there is absolutely no guarantee for that.
Usage
use thread_priority::thread_native_id;
assert!(thread_native_id() > 0);