pub struct PooledBlobSidecar { /* private fields */ }Expand description
A blob sidecar paired with its shared cell availability.
Implementations
Sourceimpl PooledBlobSidecar
impl PooledBlobSidecar
Sourcepub const fn new(
sidecar: BlobTransactionSidecarVariant,
availability: BlobCellAvailability,
) -> PooledBlobSidecar
pub const fn new( sidecar: BlobTransactionSidecarVariant, availability: BlobCellAvailability, ) -> PooledBlobSidecar
Creates a sidecar with the given shared cell availability.
Sourcepub const fn is_eip7594(&self) -> bool
pub const fn is_eip7594(&self) -> bool
Returns whether this is an EIP-7594 sidecar.
Sourcepub const fn availability(&self) -> &BlobCellAvailability
pub const fn availability(&self) -> &BlobCellAvailability
Returns the shared cell availability.
Sourcepub fn into_sidecar(self) -> BlobTransactionSidecarVariant
pub fn into_sidecar(self) -> BlobTransactionSidecarVariant
Consumes the wrapper and returns the sidecar.
Methods from Deref<Target = BlobTransactionSidecarVariant>
pub fn is_eip4844(&self) -> bool
pub fn is_eip4844(&self) -> bool
Returns true if this is a [BlobTransactionSidecarVariant::Eip4844].
pub fn is_eip7594(&self) -> bool
pub fn is_eip7594(&self) -> bool
Returns true if this is a [BlobTransactionSidecarVariant::Eip7594].
pub fn as_eip4844(&self) -> Option<&BlobTransactionSidecar>
pub fn as_eip4844(&self) -> Option<&BlobTransactionSidecar>
Returns the EIP-4844 sidecar if it is [Self::Eip4844].
pub fn as_eip7594(&self) -> Option<&BlobTransactionSidecarEip7594>
pub fn as_eip7594(&self) -> Option<&BlobTransactionSidecarEip7594>
Returns the EIP-7594 sidecar if it is [Self::Eip7594].
pub fn blobs(&self) -> &[FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>]
pub fn blobs(&self) -> &[FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>]
Get a reference to the blobs
pub fn size(&self) -> usize
pub fn size(&self) -> usize
Calculates a size heuristic for the in-memory size of the [BlobTransactionSidecarVariant].
pub fn validate(
&self,
blob_versioned_hashes: &[FixedBytes<32>],
proof_settings: &KZGSettings,
) -> Result<(), BlobTransactionValidationError>
Available on crate feature kzg only.
pub fn validate( &self, blob_versioned_hashes: &[FixedBytes<32>], proof_settings: &KZGSettings, ) -> Result<(), BlobTransactionValidationError>
kzg only.Verifies that the sidecar is valid. See relevant methods for each variant for more info.
pub fn commitments(&self) -> &[FixedBytes<48>]
pub fn commitments(&self) -> &[FixedBytes<48>]
Returns the commitments of the sidecar.
pub fn versioned_hashes(&self) -> VersionedHashIter<'_> ⓘ
pub fn versioned_hashes(&self) -> VersionedHashIter<'_> ⓘ
Returns an iterator over the versioned hashes of the commitments.
pub fn versioned_hash_index(&self, hash: &FixedBytes<32>) -> Option<usize>
pub fn versioned_hash_index(&self, hash: &FixedBytes<32>) -> Option<usize>
Returns the index of the versioned hash in the commitments vector.
pub fn blob_by_versioned_hash(
&self,
hash: &FixedBytes<32>,
) -> Option<&FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
pub fn blob_by_versioned_hash( &self, hash: &FixedBytes<32>, ) -> Option<&FixedBytes<alloy_eips::::eip4844::Blob::{constant#0}>>
Returns the blob corresponding to the versioned hash, if it exists.