TxPool

Struct TxPool 

pub struct TxPool<T>{ /* private fields */ }
A pool that manages transactions.

This pool maintains the state of all transactions and stores them accordingly.

graph TB
  subgraph TxPool
    direction TB
    pool[(All Transactions)]
    subgraph Subpools
        direction TB
        B3[(Queued)]
        B1[(Pending)]
        B2[(Basefee)]
        B4[(Blob)]
    end
  end
  discard([discard])
  production([Block Production])
  new([New Block])
  A[Incoming Tx] --> B[Validation] -->|ins
  pool --> |if ready + blobfee too low| B4
  pool --> |if ready| B1
  pool --> |if ready + basfee too low| B2
  pool --> |nonce gap or lack of funds| B3
  pool --> |update| pool
  B1 --> |best| production
  B2 --> |worst| discard
  B3 --> |worst| discard
  B4 --> |worst| discard
  B1 --> |increased blob fee| B4
  B4 --> |decreased blob fee| B1
  B1 --> |increased base fee| B2
  B2 --> |decreased base fee| B1
  B3 --> |promote| B1
  B3 --> |promote| B2
  new --> |apply state changes| pool

Implementations

Source

impl<T> TxPool<T>

pub fn new(ordering: T, config: PoolConfig) -> TxPool<T>

Create a new graph pool instance.

pub fn get_highest_nonce_by_sender(&self, sender: SenderId) -> Option<u64>

Retrieves the highest nonce for a specific sender from the transaction pool.

pub fn get_highest_transaction_by_sender( &self, sender: SenderId, ) -> Option<Arc<ValidPoolTransaction<<T as TransactionOrdering>::Transaction>>>

Retrieves the highest transaction (wrapped in an Arc) for a specific sender from the transaction pool.

pub fn size(&self) -> PoolSize

Returns stats about the size of pool.

pub const fn block_info(&self) -> BlockInfo

Returns the currently tracked block values

pub fn set_block_info( &mut self, info: BlockInfo, ) -> UpdateOutcome<<T as TransactionOrdering>::Transaction>

Sets the current block info for the pool.

This will also apply updates to the pool based on the new base fee and blob fee.

Returns the outcome containing any transactions that were promoted due to fee changes.

pub fn queued_and_pending_txs_by_sender( &self, sender: SenderId, ) -> (SmallVec<[TransactionId; 16]>, Vec<TransactionId>)

Returns queued and pending transactions for the specified sender

pub fn assert_invariants(&self)

Available on crate features test-utils only.

Asserts all invariants of the pool’s:

  • All maps are bijections (by_id, by_hash)
  • Total size is equal to the sum of all sub-pools
Panics

if any invariant is violated

Source

impl TxPool<CoinbaseTipOrdering<MockTransaction>>

pub fn mock() -> TxPool<CoinbaseTipOrdering<MockTransaction>>

Available on crate features test-utils only.

Creates a mock instance for testing.

Source

impl<T> TxPool<T>

pub const fn pending(&self) -> &PendingPool<T>

Pending subpool

pub const fn base_fee( &self, ) -> &ParkedPool<BasefeeOrd<<T as TransactionOrdering>::Transaction>>

Base fee subpool

pub const fn queued( &self, ) -> &ParkedPool<QueuedOrd<<T as TransactionOrdering>::Transaction>>

Queued sub pool