pub fn ensure_intrinsic_gas<T>(
transaction: &T,
fork_tracker: &ForkTracker,
) -> Result<(), InvalidPoolTransactionError>where
T: EthPoolTransaction,Expand description
Ensures that gas limit of the transaction exceeds the intrinsic gas of the transaction, and that its intrinsic regular gas fits the EIP-8037 regular gas cap.
Caution: This only checks past the Merge hardfork.