pub trait ReceiptsClient: DownloadClient {
type Receipt: TxReceipt;
type Output: Future<Output = Result<WithPeerId<ReceiptsResponse<Self::Receipt>>, RequestError>> + Sync + Send + Unpin;
// Required method
fn get_receipts_with_priority(
&self,
hashes: Vec<FixedBytes<32>>,
priority: Priority,
) -> Self::Output;
// Provided method
fn get_receipts(&self, hashes: Vec<FixedBytes<32>>) -> Self::Output { ... }
}Expand description
A client capable of downloading block receipts from peers.
Required Associated Types
Sourcetype Output: Future<Output = Result<WithPeerId<ReceiptsResponse<Self::Receipt>>, RequestError>> + Sync + Send + Unpin
type Output: Future<Output = Result<WithPeerId<ReceiptsResponse<Self::Receipt>>, RequestError>> + Sync + Send + Unpin
The output of the request future for querying block receipts.
Required Methods
Sourcefn get_receipts_with_priority(
&self,
hashes: Vec<FixedBytes<32>>,
priority: Priority,
) -> Self::Output
fn get_receipts_with_priority( &self, hashes: Vec<FixedBytes<32>>, priority: Priority, ) -> Self::Output
Fetches the receipts for the requested block hashes with priority.
Provided Methods
Sourcefn get_receipts(&self, hashes: Vec<FixedBytes<32>>) -> Self::Output
fn get_receipts(&self, hashes: Vec<FixedBytes<32>>) -> Self::Output
Fetches the receipts for the requested block hashes.