pub struct TxPool<T>where
T: TransactionOrdering,{ /* private fields */ }Expand description
A pool that manages transactions.
This pool maintains the state of all transactions and stores them accordingly.
graph TB
subgraph TxPool
direction TB
pool[(All Transactions)]
subgraph Subpools
direction TB
B3[(Queued)]
B1[(Pending)]
B2[(Basefee)]
B4[(Blob)]
end
end
discard([discard])
production([Block Production])
new([New Block])
A[Incoming Tx] --> B[Validation] -->|ins
pool --> |if ready + blobfee too low| B4
pool --> |if ready| B1
pool --> |if ready + basfee too low| B2
pool --> |nonce gap or lack of funds| B3
pool --> |update| pool
B1 --> |best| production
B2 --> |worst| discard
B3 --> |worst| discard
B4 --> |worst| discard
B1 --> |increased blob fee| B4
B4 --> |decreased blob fee| B1
B1 --> |increased base fee| B2
B2 --> |decreased base fee| B1
B3 --> |promote| B1
B3 --> |promote| B2
new --> |apply state changes| poolImplementations
Sourceimpl<T> TxPool<T>where
T: TransactionOrdering,
impl<T> TxPool<T>where
T: TransactionOrdering,
Sourcepub fn new(ordering: T, config: PoolConfig) -> TxPool<T>
pub fn new(ordering: T, config: PoolConfig) -> TxPool<T>
Create a new graph pool instance.
Sourcepub fn get_highest_nonce_by_sender(&self, sender: SenderId) -> Option<u64>
pub fn get_highest_nonce_by_sender(&self, sender: SenderId) -> Option<u64>
Retrieves the highest nonce for a specific sender from the transaction pool.
Sourcepub fn get_highest_transaction_by_sender(
&self,
sender: SenderId,
) -> Option<Arc<ValidPoolTransaction<<T as TransactionOrdering>::Transaction>>>
pub fn get_highest_transaction_by_sender( &self, sender: SenderId, ) -> Option<Arc<ValidPoolTransaction<<T as TransactionOrdering>::Transaction>>>
Retrieves the highest transaction (wrapped in an Arc) for a specific sender from the
transaction pool.
Sourcepub const fn block_info(&self) -> BlockInfo
pub const fn block_info(&self) -> BlockInfo
Returns the currently tracked block values
Sourcepub fn set_block_info(
&mut self,
info: BlockInfo,
) -> UpdateOutcome<<T as TransactionOrdering>::Transaction>
pub fn set_block_info( &mut self, info: BlockInfo, ) -> UpdateOutcome<<T as TransactionOrdering>::Transaction>
Sets the current block info for the pool.
This will also apply updates to the pool based on the new base fee and blob fee.
Returns the outcome containing any transactions that were promoted due to fee changes.
Sourcepub fn queued_and_pending_txs_by_sender(
&self,
sender: SenderId,
) -> (SmallVec<[TransactionId; 16]>, Vec<TransactionId>)
pub fn queued_and_pending_txs_by_sender( &self, sender: SenderId, ) -> (SmallVec<[TransactionId; 16]>, Vec<TransactionId>)
Returns queued and pending transactions for the specified sender
Sourcepub fn assert_invariants(&self)
Available on crate features test-utils only.
pub fn assert_invariants(&self)
test-utils only.Asserts all invariants of the pool’s:
- All maps are bijections (
by_id,by_hash) - Total size is equal to the sum of all sub-pools
Panics
if any invariant is violated
Sourceimpl TxPool<CoinbaseTipOrdering<MockTransaction>>
impl TxPool<CoinbaseTipOrdering<MockTransaction>>
Sourcepub fn mock() -> TxPool<CoinbaseTipOrdering<MockTransaction>>
Available on crate features test-utils only.
pub fn mock() -> TxPool<CoinbaseTipOrdering<MockTransaction>>
test-utils only.Creates a mock instance for testing.
Sourceimpl<T> TxPool<T>where
T: TransactionOrdering,
impl<T> TxPool<T>where
T: TransactionOrdering,
Sourcepub const fn pending(&self) -> &PendingPool<T>
pub const fn pending(&self) -> &PendingPool<T>
Pending subpool
Sourcepub const fn base_fee(
&self,
) -> &ParkedPool<BasefeeOrd<<T as TransactionOrdering>::Transaction>>
pub const fn base_fee( &self, ) -> &ParkedPool<BasefeeOrd<<T as TransactionOrdering>::Transaction>>
Base fee subpool
Sourcepub const fn queued(
&self,
) -> &ParkedPool<QueuedOrd<<T as TransactionOrdering>::Transaction>>
pub const fn queued( &self, ) -> &ParkedPool<QueuedOrd<<T as TransactionOrdering>::Transaction>>
Queued sub pool